==> 1.0.0.tar.gz: ios/Classes/MethodCallHandlerImpl.swift <==
//
//  MethodCallHandlerImpl.swift
//  fl_location
//
//  Created by WOO JIN HWANG on 2021/07/26.
//

import Flutter
import Foundation

class MethodCallHandlerImpl: NSObject, LocationPermissionHandler, LocationDataHandler {
  private let channel: FlutterMethodChannel
  private let serviceProvider: ServiceProvider
  
  private var locationPermissionResult: FlutterResult? = nil
  private var locationDataResult: FlutterResult? = nil
  
  init(messenger: FlutterBinaryMessenger, serviceProvider: ServiceProvider) {
    self.channel = FlutterMethodChannel(name: "plugins.pravera.com/fl_location", binaryMessenger: messenger)
    self.serviceProvider = serviceProvider
    super.init()
    self.channel.setMethodCallHandler(onMethodCall)
  }
  
  func onMethodCall(call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
      case "checkLocationServicesStatus":
        result(LocationServicesUtils.checkLocationServicesStatus().rawValue)
      case "checkLocationPermission":
        locationPermissionResult = result
        serviceProvider.getLocationPermissionManager().checkLocationPermission(handler: self)
      case "requestLocationPermission":
        locationPermissionResult = result
        serviceProvider.getLocationPermissionManager().requestLocationPermission(handler: self)
      case "getLocation":
        let argsDict = call.arguments as? Dictionary<String, Any>
        let settings = LocationSettings(from: argsDict)
        
        locationDataResult = result
        serviceProvider.getLocationDataProvider().startUpdatingLocation(handler: self, settings: settings)
      default:
        result(FlutterMethodNotImplemented)
    }
  }
  
  func onPermissionResult(locationPermission: LocationPermission) {
    locationPermissionResult?(locationPermission.rawValue)
    locationPermissionResult = nil
  }
  
  func onPermissionError(errorCode: ErrorCodes) {
    if locationPermissionResult == nil { return }
    ErrorHandleUtils.handleMethodCallError(result: locationPermissionResult!, errorCode: errorCode)
    locationPermissionResult = nil
  }
  
  func onLocationUpdate(locationJson: String) {
    serviceProvider.getLocationDataProvider().stopUpdatingLocation()
    
    locationDataResult?(locationJson)
    locationDataResult = nil
  }
  
  func onLocationError(errorCode: ErrorCodes) {
    serviceProvider.getLocationDataProvider().stopUpdatingLocation()
    
    if locationDataResult == nil { return }
    ErrorHandleUtils.handleMethodCallError(result: locationDataResult!, errorCode: errorCode)
    locationDataResult = nil
  }
}

==> 1.2.0.tar.gz: ios/Classes/MethodCallHandlerImpl.swift <==
//
//  MethodCallHandlerImpl.swift
//  fl_location
//
//  Created by WOO JIN HWANG on 2021/07/26.
//

import Flutter
import Foundation

class MethodCallHandlerImpl: NSObject {
  private let channel: FlutterMethodChannel
  private let serviceProvider: ServiceProvider
  
  init(messenger: FlutterBinaryMessenger, serviceProvider: ServiceProvider) {
    self.channel = FlutterMethodChannel(name: "plugins.pravera.com/fl_location", binaryMessenger: messenger)
    self.serviceProvider = serviceProvider
    super.init()
    self.channel.setMethodCallHandler(onMethodCall)
  }
  
  func onMethodCall(call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
      case "checkLocationServicesStatus":
        result(LocationServicesUtils.checkLocationServicesStatus().rawValue)
      case "checkLocationPermission":
        let handler = LocationPermissionHandlerImpl(result)
        serviceProvider.getLocationPermissionManager().checkLocationPermission(handler: handler)
      case "requestLocationPermission":
        let handler = LocationPermissionHandlerImpl(result)
        serviceProvider.getLocationPermissionManager().requestLocationPermission(handler: handler)
      case "getLocation":
        let argsDict = call.arguments as? Dictionary<String, Any>
        let settings = LocationSettings(from: argsDict)
        
        let handler = LocationDataHandlerImpl(result)
        serviceProvider
          .getLocationDataProviderManager()
          .getLocation(handler: handler, settings: settings)
      default:
        result(FlutterMethodNotImplemented)
    }
  }
}
